# -*- coding: utf-8 -*-


from django import forms
from django.utils.translation import ugettext_lazy

from job_offers.models import JobOffer, Application, ContractType


class ApplicationForm(forms.ModelForm):
    """Form for job application"""

    class Meta:
        model = Application
        fields = [
            'message',
            'last_name',
            'first_name',
            'email',
            'phone',
            'cv',
            'cover_letter',
            'other_document',
        ]


def get_locations():
    yield ('', '-------')
    qs = JobOffer.objects.active().values_list('location', flat=True).distinct()
    for location in qs:
        yield location, location


class SearchForm(forms.Form):
    keywords = forms.CharField(
        label=ugettext_lazy('Keywords'),
        max_length=100,
        required=False
    )
    order = forms.ChoiceField(
        choices=[
            ('title', ugettext_lazy('Title')),
            ('country', ugettext_lazy('Country')),
            ('contract_type', ugettext_lazy('Type of contract')),
        ],
        required=False,
    )
    reverse = forms.BooleanField(
        required=False,
    )
    contract_type = forms.ModelChoiceField(
        queryset=ContractType.objects,
        to_field_name='title',
        required=False
    )
    location = forms.ChoiceField(
        choices=get_locations,
        required=False,
    )

    def clean_keywords(self):
        return self.cleaned_data['keywords'].split()
